# Contributing

BeeWare <3's contributions!

Please be aware, BeeWare operates under a Code of Conduct.

See [CONTRIBUTING to BeeWare](https://beeware.org/contributing) for details.

See also the Briefcase specific contributing guides for contributing
[code](https://briefcase.readthedocs.io/en/latest/how-to/contribute-code.html)
and
[documentation](https://briefcase.readthedocs.io/en/latest/how-to/contribute-docs.html)
